Attribute VB_Name = "CiMiscFnc"
Option Explicit
'===================================================================
' This file is provided as part of the ClearImage COM Development Kit
'
' THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT
' WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED,
' INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES
' OF MERCHANTABILITY AND/OR FITNESS FOR A  PARTICULAR PURPOSE.
'
' Copyright (C) 2003.  Inlite Research, Inc. All rights reserved
'===================================================================

Private Declare Function GetSaveFileName Lib "comdlg32.dll" Alias _
         "GetSaveFileNameA" (pOpenfilename As OPENFILENAME) As Long
         
Private Declare Function GetOpenFileName Lib "comdlg32.dll" Alias _
         "GetOpenFileNameA" (pOpenfilename As OPENFILENAME) As Long
         
Private Type OPENFILENAME
  lStructSize As Long
  hwndOwner As Long
  hInstance As Long
  lpstrFilter As String
  lpstrCustomFilter As String
  nMaxCustFilter As Long
  nFilterIndex As Long
  lpstrFile As String
  nMaxFile As Long
  lpstrFileTitle As String
  nMaxFileTitle As Long
  lpstrInitialDir As String
  lpstrTitle As String
  Flags As Long
  nFileOffset As Integer
  nFileExtension As Integer
  lpstrDefExt As String
  lCustData As Long
  lpfnHook As Long
  lpTemplateName As String
End Type
  
Public Const MB_BASIC = 0
Public Const MB_PRO = 1
Public Const MB_PDF417 = 2
Public Const MB_DATAMATRIX = 3

Public Sub ShowError(Optional sMsg = "")
  Dim str As String
  If Err.Number <> 0 Then
    If (sMsg <> "") Then str = sMsg & vbCrLf
    str = str & "Error from " & Err.Source & vbCrLf
    str = str & Err.Description & vbCrLf
    str = str & "HRESULT: " & "0x" & Hex$(Err.Number)
    MsgBox str
    Err.Clear
  End If
End Sub

Public Function FileOpenDialog(sFileName As String) As String
  FileOpenDialog = ""
  On Error GoTo except
  Dim OpenFile As OPENFILENAME
  Dim lReturn As Long
  Dim sFilter As String
  OpenFile.lStructSize = Len(OpenFile)
  OpenFile.hwndOwner = 0
  OpenFile.hInstance = App.hInstance
  sFilter = "Image Files (*.tif, *.jpg, *.bmp)" & Chr(0) & "*.tif;*.jpg;*.bmp" & Chr(0)
  sFilter = sFilter + "All Files (*.*)" & Chr(0) & "*.*" & Chr(0) & Chr(0)
  OpenFile.lpstrFilter = sFilter
  OpenFile.nFilterIndex = 1
  Dim sName: sName = sFileName
  OpenFile.lpstrFile = sName + String(1024 - Len(sName), 0)
  OpenFile.nMaxFile = Len(OpenFile.lpstrFile) - 1
  OpenFile.lpstrFileTitle = OpenFile.lpstrFile
  OpenFile.nMaxFileTitle = OpenFile.nMaxFile
  OpenFile.lpstrTitle = "Enter File Name"
  OpenFile.Flags = 0
  lReturn = GetOpenFileName(OpenFile)
  If lReturn <> 0 Then ' 0 - Cancel was pressed
    FileOpenDialog = OpenFile.lpstrFile
    FileOpenDialog = StripNulls(FileOpenDialog)
  End If
  Exit Function
except:
  ShowError "FOD"
End Function

Public Function StripNulls(sIn) As String
  StripNulls = sIn
  Dim ind: ind = InStr(sIn, Chr(0))
  If (ind > 0) Then StripNulls = Left(sIn, ind - 1)
End Function

Public Function SetExt(sIn, sExt) As String
  SetExt = sIn
  If (sExt = "") Then Exit Function
  Dim ind: ind = InStrRev(sIn, ".")
  If (ind = 0) Then
    SetExt = sIn & "." & sExt
  Else
    SetExt = Left(sIn, ind) & sExt
  End If
End Function

Public Function FileSaveDialog(sFileName As String, Optional bAppend = False) As String
  FileSaveDialog = ""
  On Error GoTo except
  Dim OpenFile As OPENFILENAME
  Dim lReturn As Long
  Dim sFilter As String
  OpenFile.lStructSize = Len(OpenFile)
  OpenFile.hwndOwner = 0
  OpenFile.hInstance = App.hInstance
  sFilter = sFilter + "TIF Files (*.tif)" & Chr(0) & "*.tif" & Chr(0)
  If (Not bAppend) Then
    sFilter = sFilter + "BMP Files (*.bmp)" & Chr(0) & "*.bmp" & Chr(0)
    sFilter = sFilter + "JPG Files (*.jpg)" & Chr(0) & "*.jpg" & Chr(0)
  End If
  sFilter = sFilter + "All Files (*.*)" & Chr(0) & "*.*" & Chr(0) & Chr(0)
  OpenFile.lpstrFilter = sFilter
  OpenFile.nFilterIndex = 1
  Dim sName: sName = sFileName
  OpenFile.lpstrFile = sName + String(1024 - Len(sName), 0)
  OpenFile.nMaxFile = Len(OpenFile.lpstrFile) - 1
  OpenFile.lpstrFileTitle = OpenFile.lpstrFile
  OpenFile.nMaxFileTitle = OpenFile.nMaxFile
  OpenFile.lpstrTitle = "Enter File Name"
  OpenFile.Flags = 0 ' cdlOFNExplorer Or cdlOFNOverwritePrompt Or cdlOFNPathMustExist
  lReturn = GetSaveFileName(OpenFile)
  If lReturn <> 0 Then ' 0 - Cancel was pressed
    FileSaveDialog = OpenFile.lpstrFile
    FileSaveDialog = StripNulls(FileSaveDialog)
    FileSaveDialog = SetExt(FileSaveDialog, Choose(OpenFile.nFilterIndex, "tif", "bmp", "jpg", ""))
  End If
  Exit Function
except:
  ShowError "FSD"
End Function

Public Function RectToString(ByRef r) As String
  RectToString = r.Left & ":" & r.Top & "-" & r.Right & ":" & r.bottom
End Function

Public Function BinToHex(sIn As String, Optional bSaveAscii = False) As String
  Dim bInHex: bInHex = False
  Dim nPos, sOut, c, n As Integer: sOut = ""
  Dim cToBin, cFromBin:   cToBin = Chr(16): cFromBin = Chr(17)
  bInHex = Not bSaveAscii
  For nPos = 1 To Len(sIn)
    c = Mid(sIn, nPos, 1)
    n = Asc(c)
    If ((Not bSaveAscii) Or ((n < 32 Or n >= 127) And Not (n = 10 Or n = 13))) Then
      If (Not bInHex) Then sOut = sOut + cToBin
      bInHex = True
      sOut = sOut & IIf(n < 16, "0", "") & LCase(Hex(n)) & " "
    Else
      If (bInHex) Then sOut = sOut + cFromBin
      bInHex = False
      sOut = sOut + c
    End If
  Next
  BinToHex = sOut
End Function




